@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2009-2010  Nokia Corporation and/or its subsidiary(-ies)
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2009-2010  Nokia Corporation and/or its subsidiary(-ies).
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,7 +29,6 @@
 #include <gisi/pep.h>
 #include <gisi/pipe.h>
 
-#include "isimodem.h"
 #include "isiutil.h"
 #include "gpds.h"
 #include "debug.h"
@@ -534,17 +519,14 @@ static void isi_gprs_activate_primary(struct ofono_gprs_context *gc,
 			|| strlen(ctx->password) >= GPDS_MAX_PASSWORD_LENGTH)
 		goto error;
 
-	strncpy(cd->apn, ctx->apn, GPDS_MAX_APN_STRING_LENGTH);
-	cd->apn[GPDS_MAX_APN_STRING_LENGTH] = '\0';
+	g_strlcpy(cd->apn, ctx->apn, sizeof(cd->apn));
 
 	if (ctx->auth_method == OFONO_GPRS_AUTH_METHOD_NONE) {
 		memset(cd->username, 0, sizeof(cd->username));
 		memset(cd->password, 0, sizeof(cd->password));
 	} else {
-		strncpy(cd->username, ctx->username, GPDS_MAX_USERNAME_LENGTH);
-		cd->username[GPDS_MAX_USERNAME_LENGTH] = '\0';
-		strncpy(cd->password, ctx->password, GPDS_MAX_PASSWORD_LENGTH);
-		cd->password[GPDS_MAX_PASSWORD_LENGTH] = '\0';
+		g_strlcpy(cd->username, ctx->username, sizeof(cd->username));
+		g_strlcpy(cd->password, ctx->password, sizeof(cd->password));
 	}
 
 	cd->pep = g_isi_pep_create(cd->idx, NULL, NULL);
@@ -663,19 +645,10 @@ static void isi_gprs_context_remove(struct ofono_gprs_context *gc)
 }
 
 static const struct ofono_gprs_context_driver driver = {
-	.name			= "isimodem",
 	.probe			= isi_gprs_context_probe,
 	.remove			= isi_gprs_context_remove,
 	.activate_primary	= isi_gprs_activate_primary,
 	.deactivate_primary	= isi_gprs_deactivate_primary,
 };
 
-void isi_gprs_context_init(void)
-{
-	ofono_gprs_context_driver_register(&driver);
-}
-
-void isi_gprs_context_exit(void)
-{
-	ofono_gprs_context_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(gprs_context, isimodem, &driver)
