@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2011-2012  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2011-2012  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,8 +18,7 @@
 
 #include "qmi.h"
 #include "wms.h"
-
-#include "qmimodem.h"
+#include "util.h"
 
 struct sms_data {
 	struct qmi_service *wms;
@@ -98,12 +83,12 @@ static void qmi_sca_query(struct ofono_sms *sms,
 	DBG("");
 
 	if (qmi_service_send(data->wms, QMI_WMS_GET_SMSC_ADDR, NULL,
-					get_smsc_addr_cb, cbd, g_free) > 0)
+					get_smsc_addr_cb, cbd, l_free) > 0)
 		return;
 
 	CALLBACK_WITH_FAILURE(cb, NULL, cbd->data);
 
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static void set_smsc_addr_cb(struct qmi_result *result, void *user_data)
@@ -146,8 +131,6 @@ static void qmi_sca_set(struct ofono_sms *sms,
 	snprintf(type, sizeof(type), "%d", sca->type);
 
 	param = qmi_param_new();
-	if (!param)
-		goto error;
 
 	qmi_param_append(param, QMI_WMS_PARAM_SMSC_ADDR,
 						strlen(number), number);
@@ -155,15 +138,14 @@ static void qmi_sca_set(struct ofono_sms *sms,
 						strlen(type), type);
 
 	if (qmi_service_send(data->wms, QMI_WMS_SET_SMSC_ADDR, param,
-					set_smsc_addr_cb, cbd, g_free) > 0)
+					set_smsc_addr_cb, cbd, l_free) > 0)
 		return;
 
 	qmi_param_free(param);
 
 error:
 	CALLBACK_WITH_FAILURE(cb, cbd->data);
-
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static void raw_send_cb(struct qmi_result *result, void *user_data)
@@ -201,25 +183,20 @@ static void qmi_submit(struct ofono_sms *sms,
 	message = alloca(3 + pdu_len);
 
 	message->msg_format = 0x06;
-	message->msg_length = GUINT16_TO_LE(pdu_len);
+	message->msg_length = L_CPU_TO_LE16(pdu_len);
 	memcpy(message->msg_data, pdu, pdu_len);
 
 	param = qmi_param_new();
-	if (!param)
-		goto error;
 
 	qmi_param_append(param, QMI_WMS_PARAM_MESSAGE, 3 + pdu_len, message);
 
 	if (qmi_service_send(data->wms, QMI_WMS_RAW_SEND, param,
-					raw_send_cb, cbd, g_free) > 0)
+					raw_send_cb, cbd, l_free) > 0)
 		return;
 
 	qmi_param_free(param);
-
-error:
 	CALLBACK_WITH_FAILURE(cb, -1, cbd->data);
-
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static int domain_to_bearer(uint8_t domain)
@@ -290,13 +267,13 @@ static void qmi_bearer_query(struct ofono_sms *sms,
 		goto error;
 
 	if (qmi_service_send(data->wms, QMI_WMS_GET_DOMAIN_PREF, NULL,
-					get_domain_pref_cb, cbd, g_free) > 0)
+					get_domain_pref_cb, cbd, l_free) > 0)
 		return;
 
 error:
 	CALLBACK_WITH_FAILURE(cb, -1, cbd->data);
 
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static void set_domain_pref_cb(struct qmi_result *result, void *user_data)
@@ -330,17 +307,16 @@ static void qmi_bearer_set(struct ofono_sms *sms, int bearer,
 	domain = bearer_to_domain(bearer);
 
 	param = qmi_param_new_uint8(QMI_WMS_PARAM_DOMAIN, domain);
-	if (!param)
-		goto error;
 
 	if (qmi_service_send(data->wms, QMI_WMS_SET_DOMAIN_PREF, param,
-					set_domain_pref_cb, cbd, g_free) > 0)
+					set_domain_pref_cb, cbd, l_free) > 0)
 		return;
 
+	qmi_param_free(param);
+
 error:
 	CALLBACK_WITH_FAILURE(cb, cbd->data);
-
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static void delete_msg_cb(struct qmi_result *result, void *user_data)
@@ -367,7 +343,7 @@ static void delete_msg_cb(struct qmi_result *result, void *user_data)
 		 */
 		if (msg < data->msg_list->cnt)
 			raw_read(sms, data->msg_list->msg[msg].type,
-				GUINT32_FROM_LE(data->msg_list->msg[msg].ndx));
+				L_LE32_TO_CPU(data->msg_list->msg[msg].ndx));
 		else
 			get_msg_list(sms);
 	}
@@ -382,8 +358,6 @@ static void delete_msg(struct ofono_sms *sms, uint8_t tag)
 	DBG("");
 
 	param = qmi_param_new();
-	if (param == NULL)
-		goto done;
 
 	qmi_param_append_uint8(param, QMI_WMS_PARAM_DEL_STORE,
 				QMI_WMS_STORAGE_TYPE_NV);
@@ -410,8 +384,6 @@ static void delete_msg(struct ofono_sms *sms, uint8_t tag)
 		return;
 
 	qmi_param_free(param);
-
-done:
 	data->msg_list_chk = false;
 }
 
@@ -436,7 +408,7 @@ static void raw_read_cb(struct qmi_result *result, void *user_data)
 		uint16_t plen;
 		uint16_t tpdu_len;
 
-		plen = GUINT16_FROM_LE(msg->msg_length);
+		plen = L_LE16_TO_CPU(msg->msg_length);
 		tpdu_len = plen - msg->msg_data[0] - 1;
 
 		ofono_sms_deliver_notify(sms, msg->msg_data, plen, tpdu_len);
@@ -456,8 +428,6 @@ static void raw_read(struct ofono_sms *sms, uint8_t type, uint32_t ndx)
 	DBG("");
 
 	param = qmi_param_new();
-	if (param == NULL)
-		goto done;
 
 	data->rd_msg_id.type = type;
 	data->rd_msg_id.ndx = ndx;
@@ -473,8 +443,6 @@ static void raw_read(struct ofono_sms *sms, uint8_t type, uint32_t ndx)
 		return;
 
 	qmi_param_free(param);
-
-done:
 	data->msg_list_chk = false;
 }
 
@@ -500,17 +468,17 @@ static void get_msg_list_cb(struct qmi_result *result, void *user_data)
 		goto done;
 	}
 
-	cnt = GUINT32_FROM_LE(list->cnt);
+	cnt = L_LE32_TO_CPU(list->cnt);
 	DBG("msgs found %d", cnt);
 
 	for (tmp = 0; tmp < cnt; tmp++) {
 		DBG("unread type %d ndx %d", list->msg[tmp].type,
-			GUINT32_FROM_LE(list->msg[tmp].ndx));
+			L_LE32_TO_CPU(list->msg[tmp].ndx));
 	}
 
 	/* free list from last time */
 	if (data->msg_list) {
-		g_free(data->msg_list);
+		l_free(data->msg_list);
 		data->msg_list = NULL;
 	}
 
@@ -518,16 +486,13 @@ static void get_msg_list_cb(struct qmi_result *result, void *user_data)
 	if (cnt) {
 		int msg_size = cnt * sizeof(list->msg[0]);
 
-		data->msg_list = g_try_malloc0(sizeof(list->cnt) + msg_size);
-		if (data->msg_list == NULL)
-			goto done;
-
+		data->msg_list = l_malloc(sizeof(list->cnt) + msg_size);
 		data->msg_list->cnt = cnt;
 		memcpy(data->msg_list->msg, list->msg, msg_size);
 
 		data->rd_msg_num = 0;
 		raw_read(sms, data->msg_list->msg[0].type,
-				GUINT32_FROM_LE(data->msg_list->msg[0].ndx));
+				L_LE32_TO_CPU(data->msg_list->msg[0].ndx));
 		return;
 	}
 
@@ -550,8 +515,6 @@ static void get_msg_list(struct ofono_sms *sms)
 	DBG("");
 
 	param = qmi_param_new();
-	if (param == NULL)
-		return;
 
 	data->msg_list_chk = true;
 
@@ -579,21 +542,23 @@ static void get_msg_protocol_cb(struct qmi_result *result, void *user_data)
 
 	DBG("");
 
-	if (qmi_result_set_error(result, &err) &&
-			(err != QMI_ERR_OP_DEVICE_UNSUPPORTED)) {
-		DBG("Err: protocol %d - %s", err, qmi_result_get_error(result));
-		return;
-	}
+	if (qmi_result_set_error(result, &err)) {
+		if (err != QMI_ERR_OP_DEVICE_UNSUPPORTED) {
+			DBG("Err: protocol %d - %s",
+					err, qmi_result_get_error(result));
+			return;
+		}
 
-	if (err != QMI_ERR_OP_DEVICE_UNSUPPORTED) {
-		/* modem supports only 1 protocol */
-		qmi_result_get_uint8(result, QMI_WMS_PARAM_PROTOCOL,
-					&data->msg_mode);
-	} else {
-		/* check both, start with 1 then switch to other */
-		DBG("device supports CDMA and WCDMA msg protocol");
+		/* Get Message Protocol operation is not supported */
+		DBG("query both CDMA and WCDMA");
 		data->msg_mode_all = true;
 		data->msg_mode = QMI_WMS_MESSAGE_MODE_CDMA;
+	} else {
+		/* Query of current protocol succeeded, use that */
+		qmi_result_get_uint8(result, QMI_WMS_PARAM_PROTOCOL,
+					&data->msg_mode);
+
+		DBG("msg_mode: %s", data->msg_mode ? "WCDMA" : "CDMA");
 	}
 
 	/* check for messages */
@@ -632,12 +597,12 @@ static void event_notify(struct qmi_result *result, void *user_data)
 			DBG("msg mode not found, use mode %d", data->msg_mode);
 
 		DBG("msg type %d ndx %d mode %d", notify->storage_type,
-			GUINT32_FROM_LE(notify->storage_index), data->msg_mode);
+			L_LE32_TO_CPU(notify->storage_index), data->msg_mode);
 
 		/* don't read if list is being processed, get this msg later */
 		if (!data->msg_list_chk)
 			raw_read(sms, notify->storage_type,
-					GUINT32_FROM_LE(notify->storage_index));
+					L_LE32_TO_CPU(notify->storage_index));
 	} else {
 		/* route is either transfer only or transfer and ACK */
 		const struct qmi_wms_result_message *message;
@@ -646,11 +611,11 @@ static void event_notify(struct qmi_result *result, void *user_data)
 		if (message) {
 			uint16_t plen;
 
-			plen = GUINT16_FROM_LE(message->msg_length);
+			plen = L_LE16_TO_CPU(message->msg_length);
 
 			DBG("ack_required %d transaction id %u",
 				message->ack_required,
-				GUINT32_FROM_LE(message->transaction_id));
+				L_LE32_TO_CPU(message->transaction_id));
 			DBG("msg format %d PDU length %d",
 				message->msg_format, plen);
 
@@ -708,7 +673,7 @@ static void get_routes_cb(struct qmi_result *result, void *user_data)
         if (!list)
 		goto done;
 
-	num = GUINT16_FROM_LE(list->count);
+	num = L_LE16_TO_CPU(list->count);
 
 	DBG("found %d routes", num);
 
@@ -725,15 +690,13 @@ static void get_routes_cb(struct qmi_result *result, void *user_data)
 	len = 2 + (1 * 4);
 	new_list = alloca(len);
 
-	new_list->count = GUINT16_TO_LE(1);
+	new_list->count = L_CPU_TO_LE16(1);
 	new_list->route[0].msg_type = QMI_WMS_MSG_TYPE_P2P;
 	new_list->route[0].msg_class = QMI_WMS_MSG_CLASS_NONE;
 	new_list->route[0].storage_type = QMI_WMS_STORAGE_TYPE_NV;
 	new_list->route[0].action = QMI_WMS_ACTION_STORE_AND_NOTIFY;
 
 	param = qmi_param_new();
-	if (!param)
-		goto done;
 
 	qmi_param_append(param, QMI_WMS_PARAM_ROUTE_LIST, len, new_list);
 	qmi_param_append_uint8(param, QMI_WMS_PARAM_STATUS_REPORT, 0x01);
@@ -782,7 +745,7 @@ static void create_wms_cb(struct qmi_service *service, void *user_data)
 		return;
 	}
 
-	data->wms = qmi_service_ref(service);
+	data->wms = service;
 
 	memset(&data->rd_msg_id, 0, sizeof(data->rd_msg_id));
 	data->msg_mode = QMI_WMS_MESSAGE_MODE_GSMWCDMA;
@@ -791,14 +754,11 @@ static void create_wms_cb(struct qmi_service *service, void *user_data)
 					event_notify, sms, NULL);
 
 	param = qmi_param_new_uint8(QMI_WMS_PARAM_NEW_MSG_REPORT, 0x01);
-	if (!param)
-		goto done;
 
 	if (qmi_service_send(data->wms, QMI_WMS_SET_EVENT, param,
 					set_event_cb, sms, NULL) > 0)
 		return;
 
-done:
 	ofono_sms_register(sms);
 }
 
@@ -810,11 +770,12 @@ static int qmi_sms_probe(struct ofono_sms *sms,
 
 	DBG("");
 
-	data = g_new0(struct sms_data, 1);
+	data = l_new(struct sms_data, 1);
 
 	ofono_sms_set_data(sms, data);
 
-	qmi_service_create(device, QMI_SERVICE_WMS, create_wms_cb, sms, NULL);
+	qmi_service_create_shared(device, QMI_SERVICE_WMS, create_wms_cb, sms,
+					NULL);
 
 	return 0;
 }
@@ -827,18 +788,15 @@ static void qmi_sms_remove(struct ofono_sms *sms)
 
 	ofono_sms_set_data(sms, NULL);
 
-	qmi_service_unregister_all(data->wms);
-
-	qmi_service_unref(data->wms);
+	qmi_service_free(data->wms);
 
 	if (data->msg_list)
-		g_free(data->msg_list);
+		l_free(data->msg_list);
 
-	g_free(data);
+	l_free(data);
 }
 
 static const struct ofono_sms_driver driver = {
-	.name		= "qmimodem",
 	.probe		= qmi_sms_probe,
 	.remove		= qmi_sms_remove,
 	.sca_query	= qmi_sca_query,
@@ -848,12 +806,4 @@ static const struct ofono_sms_driver driver = {
 	.bearer_set	= qmi_bearer_set,
 };
 
-void qmi_sms_init(void)
-{
-	ofono_sms_driver_register(&driver);
-}
-
-void qmi_sms_exit(void)
-{
-	ofono_sms_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(sms, qmimodem, &driver)
