@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifndef __OFONO_CALL_VOLUME_H
@@ -35,7 +21,6 @@ typedef void (*ofono_call_volume_cb_t)(const struct ofono_error *error,
 					void *data);
 
 struct ofono_call_volume_driver {
-	const char *name;
 	int (*probe)(struct ofono_call_volume *cv, unsigned int vendor,
 			void *data);
 	void (*remove)(struct ofono_call_volume *cv);
@@ -50,15 +35,11 @@ struct ofono_call_volume_driver {
 };
 
 void ofono_call_volume_set_speaker_volume(struct ofono_call_volume *cv,
-					unsigned char percent);
+						unsigned char percent);
 void ofono_call_volume_set_microphone_volume(struct ofono_call_volume *cv,
 						unsigned char percent);
 void ofono_call_volume_set_muted(struct ofono_call_volume *cv, int muted);
 
-int ofono_call_volume_driver_register(const struct ofono_call_volume_driver *d);
-void ofono_call_volume_driver_unregister(
-			const struct ofono_call_volume_driver *d);
-
 struct ofono_call_volume *ofono_call_volume_create(struct ofono_modem *modem,
 			unsigned int vendor, const char *driver, void *data);
 
