@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2013  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2013  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -309,14 +295,12 @@ static gboolean sco_connect_cb(GIOChannel *io, GIOCondition cond,
 
 {
 	struct ofono_handsfree_card *card = user_data;
-	DBusMessage *reply;
+	DBusMessage *reply = NULL;
 	int sk;
 
-	if (agent == NULL) {
-		/* There's no agent, so there's no one to reply to */
-		reply = NULL;
+	/* There's no agent, so there's no one to reply to */
+	if (agent == NULL)
 		goto done;
-	}
 
 	if (cond & (G_IO_ERR | G_IO_HUP | G_IO_NVAL)) {
 		if (card->msg)
@@ -467,10 +451,8 @@ void *ofono_handsfree_card_get_data(struct ofono_handsfree_card *card)
 void ofono_handsfree_card_set_remote(struct ofono_handsfree_card *card,
 					const char *remote)
 {
-	if (card->remote)
-		g_free(card->remote);
-
-	card->remote = g_strdup(remote);
+	l_free(card->remote);
+	card->remote = l_strdup(remote);
 }
 
 const char *ofono_handsfree_card_get_remote(struct ofono_handsfree_card *card)
@@ -481,10 +463,8 @@ const char *ofono_handsfree_card_get_remote(struct ofono_handsfree_card *card)
 void ofono_handsfree_card_set_local(struct ofono_handsfree_card *card,
 					const char *local)
 {
-	if (card->local)
-		g_free(card->local);
-
-	card->local = g_strdup(local);
+	l_free(card->local);
+	card->local = l_strdup(local);
 }
 
 const char *ofono_handsfree_card_get_local(struct ofono_handsfree_card *card)
@@ -583,7 +563,7 @@ int ofono_handsfree_card_register(struct ofono_handsfree_card *card)
 
 	next_card_id += 1;
 
-	card->path = g_strdup(path);
+	card->path = l_strdup(path);
 	emit_card_added(card);
 
 	return 0;
@@ -608,7 +588,7 @@ static void card_unregister(struct ofono_handsfree_card *card)
 
 	emit_card_removed(card);
 
-	g_free(card->path);
+	l_free(card->path);
 	card->path = NULL;
 }
 
@@ -624,8 +604,8 @@ void ofono_handsfree_card_remove(struct ofono_handsfree_card *card)
 
 	card_list = g_slist_remove(card_list, card);
 
-	g_free(card->remote);
-	g_free(card->local);
+	l_free(card->remote);
+	l_free(card->local);
 
 	if (card->driver && card->driver->remove)
 		card->driver->remove(card);
@@ -665,8 +645,8 @@ static void agent_free(struct agent *agent)
 	if (agent->watch > 0)
 		g_dbus_remove_watch(ofono_dbus_get_connection(), agent->watch);
 
-	g_free(agent->owner);
-	g_free(agent->path);
+	l_free(agent->owner);
+	l_free(agent->path);
 	g_free(agent);
 }
 
@@ -791,8 +771,8 @@ static DBusMessage *am_agent_register(DBusConnection *conn,
 	}
 
 	agent = g_new0(struct agent, 1);
-	agent->owner = g_strdup(sender);
-	agent->path = g_strdup(path);
+	agent->owner = l_strdup(sender);
+	agent->path = l_strdup(path);
 	agent->watch = g_dbus_add_disconnect_watch(conn, sender,
 						agent_disconnect, NULL, NULL);
 
