@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies)
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies).
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -716,7 +702,7 @@ static void radio_settings_unregister(struct ofono_atom *atom)
 	if (rs->settings) {
 		storage_close(rs->imsi, SETTINGS_STORE, rs->settings, TRUE);
 
-		g_free(rs->imsi);
+		l_free(rs->imsi);
 		rs->imsi = NULL;
 		rs->settings = NULL;
 	}
@@ -805,7 +791,7 @@ static void radio_load_settings(struct ofono_radio_settings *rs,
 		return;
 	}
 
-	rs->imsi = g_strdup(imsi);
+	rs->imsi = l_strdup(imsi);
 
 	error = NULL;
 	rs->band_gsm = g_key_file_get_integer(rs->settings, SETTINGS_GROUP,
